@@ -2,7 +2,7 @@
  * papd paths
  */
 #define _PATH_PAPDPRINTCAP	"/etc/printcap"
-#define _PATH_PAPDSPOOLDIR	"/usr/spool/lpd"
+#define _PATH_PAPDSPOOLDIR	"/var/spool/lpd"
 #define _PATH_DEVPRINTER	"/dev/printer"
 
 /*
